@@ -1,4 +1,4 @@
-from .gateway import (
+from .handler import (
     get, 
     obtener
 )
\ No newline at end of file
